==> netw-ib-ox-ag_5.34.0.orig.tar.gz: netw-ib-ox-ag-5.34.0/src/netwib-src/src/netwib/sys/iousual.c <==
/*
                                  NETWIB
                             Network library
                Copyright(c) 1999-2006 Laurent Constantin
                                  -----

  Main server    : http://www.laurentconstantin.com/
  Backup servers : http://go.to/laurentconstantin/
                   http://laurentconstantin.est-la.com/
                   http://laurentconstantin.free.fr/
                   http://membres.lycos.fr/lauconstantin/
  [my current email address is on the web servers]

                                  -----
  This file is part of Netwib.

  Netwib is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  version 2 as published by the Free Software Foundation.

  Netwib is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details (http://www.gnu.org/).

------------------------------------------------------------------------
*/

#include <netwib/inc/maininc.h>

/*-------------------------------------------------------------*/
#include "pieces/iousual_null.c"
#include "pieces/iousual_mem.c"
#include "pieces/iousual_tlv.c"
#if defined NETWIBDEF_SYSNAME_Unix
 #include "pieces/iousual_exec_unix.c"
#elif defined NETWIBDEF_SYSNAME_Windows
 #include "pieces/iousual_exec_windows.c"
#else
 #error "Unknown value for NETWIBDEF_SYSNAME"
#endif

/*-------------------------------------------------------------*/
#include "pieces/iousual_data.c"
#include "pieces/iousual_storage.c"

/*-------------------------------------------------------------*/
#include "pieces/iousual_rdwr.c"
#include "pieces/iousual_tee.c"
#include "pieces/iousual_debug.c"

==> netw-ib-ox-ag_5.36.0.orig.tar.gz: netw-ib-ox-ag-5.36.0/src/netwib-src/src/netwib/sys/iousual.c <==
/*
                                  NETWIB
                             Network library
                Copyright(c) 1999-2008 Laurent Constantin
                                  -----

  Main server   : http://www.laurentconstantin.com/
  Backup server : http://laurentconstantin.free.fr/
  [my current email address is on the web servers]

                                  -----
  This file is part of Netwib.

  Netwib is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  version 2 as published by the Free Software Foundation.

  Netwib is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details (http://www.gnu.org/).

------------------------------------------------------------------------
*/

#include <netwib/inc/maininc.h>

/*-------------------------------------------------------------*/
#include "pieces/iousual_null.c"
#include "pieces/iousual_mem.c"
#include "pieces/iousual_tlv.c"
#if defined NETWIBDEF_SYSNAME_Unix
 #include "pieces/iousual_execcommon.c"
 #include "pieces/iousual_exec_unix.c"
#elif defined NETWIBDEF_SYSNAME_Windows
 #include "pieces/iousual_exec_windows.c"
#else
 #error "Unknown value for NETWIBDEF_SYSNAME"
#endif
#include "pieces/iousual_shellserver.c"
#include "pieces/iousual_shellclient.c"

/*-------------------------------------------------------------*/
#include "pieces/iousual_data.c"
#include "pieces/iousual_storage.c"

/*-------------------------------------------------------------*/
#include "pieces/iousual_rdwr.c"
#include "pieces/iousual_tee.c"
#include "pieces/iousual_debug.c"
